@@ -6,4 +6,9 @@ class PathIsDir(Exception):
 class PathIsFile(Exception):
     """Exception raised when given path does not correspond to a directory"""
     def __str__(self):
-        return "The given path does not correspond to a directory"
\ No newline at end of file
+        return "The given path does not correspond to a directory"
+
+class InvalidParameter(Exception):
+    """Exception raised due to invalid parameters"""
+    def __str__(self):
+        return "Invalid Paramater"
\ No newline at end of file
